"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const request_1 = __importDefault(require("request"));
const assert_1 = require("../util/assert");
// Connections to services can frequently slow down due to load, congestion, maintenance,
// degradation, shaping, issues, etc.
// We don't want a part upload to abort halfway without a good reason as it might be a
// large part.
const HTTP_REQUEST_TIMEOUT = 120000; // 2 minutes.
class HTTPBadStatusError extends Error {
    constructor(status, body, url) {
        super(`${url} returned bad HTTP status of ${status} with body: ${body}`);
        this.statusCode = status;
    }
}
exports.HTTPBadStatusError = HTTPBadStatusError;
exports.getLastHeaderValue = (res, name) => {
    const val = assert_1.assertExists(res.headers[name.toLowerCase()]);
    if (Array.isArray(val)) {
        return val[val.length - 1];
    }
    return val;
};
exports.http = ({ method, url, headers, body, }) => {
    return new Promise((resolve, reject) => {
        request_1.default({
            url,
            method,
            headers,
            body,
            timeout: HTTP_REQUEST_TIMEOUT,
        }, (err, res) => {
            if (err) {
                reject(err);
            }
            else if (res.statusCode < 200 || res.statusCode > 299) {
                reject(new HTTPBadStatusError(res.statusCode, res.body, url));
            }
            else {
                resolve(res);
            }
        });
    });
};
//# sourceMappingURL=http.js.map