/// <reference types="node" />
import { HTTPRequestHeaders, HTTPRequestMethod, HTTPRequestQueryParameters } from "../util/http";
export declare const leftPad: (str: string | number, width: number, char?: string) => string;
export declare const getISOTime: () => string;
export declare const percentEncodeBytes: (str: string | number, encodeSlashes?: boolean) => string;
export declare const hashSHA256: (data: string | Buffer) => Buffer;
export declare const EMPTY_BODY_SHA256: string;
export declare const hmac: ({ secret, data, }: {
    secret: string | Buffer;
    data: string | Buffer;
}) => Buffer;
interface CanonicalRequest {
    hash: string;
    headers: string;
}
export declare const generateCanonicalRequest: ({ method, host, path, queryParameters, headers, contentSHA256, }: {
    method: HTTPRequestMethod;
    host: string;
    path: string;
    queryParameters?: HTTPRequestQueryParameters | undefined;
    headers?: HTTPRequestHeaders | undefined;
    contentSHA256: string;
}) => CanonicalRequest;
export declare const deriveSigningKey: ({ secretAccessKey, region, service, isoDate, }: {
    secretAccessKey: string;
    region: string;
    service: string;
    isoDate: string;
}) => Buffer;
export declare const sign: ({ derivedKey, stringToSign }: {
    derivedKey: string | Buffer;
    stringToSign: string | Buffer;
}) => string;
export interface AWSSignature {
    isoDateTime: string;
    method: HTTPRequestMethod;
    host: string;
    path: string;
    queryParameters?: HTTPRequestQueryParameters;
    headers?: HTTPRequestHeaders;
    contentSHA256: string;
    service: string;
    region: string;
    accessKeyId: string;
    secretAccessKey: string;
}
export declare const createAuthHeader: ({ isoDateTime, method, host, path, queryParameters, headers, contentSHA256, service, region, accessKeyId, secretAccessKey, }: AWSSignature) => string;
export {};
